==> ktouch-0.9.tar.gz: ktouch-0.9/ktouch/slideLine.h <==
/***************************************************************************
                          slideLine.h  -  description
                             -------------------
    begin                : Thu Mar 15 2001
    copyright            : (C) 2001 by Haavard Froeiland
    email                : haavard@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SLIDELINE_H
#define SLIDELINE_H

#include <qwidget.h>
#include <qpainter.h>
#include <qstring.h>
#include <qpixmap.h>
#include <qtimer.h>
#include <qfontmetrics.h>
#include <fstream.h>

class SlideLine: public QWidget
{
  Q_OBJECT

public:
 	SlideLine(QWidget *parent=0, const char *name=0);

  void setText(QString text);
  void setPixmapSize(QString text);
  static float offset;

protected:
 	void paintEvent  ( QPaintEvent * );
	void resizeEvent ( QResizeEvent * );


private:
  bool needRecreate;
  QString text;
  QPixmap *pixmap;
  QFont font;
  int pixmapSize;
  QTimer *timer;
  int pos;
  bool textChanged;

private slots:
  void slide();

};

#endif

==> ktouch-0.91.tar.gz: ktouch-0.91/ktouch/slideLine.h <==
/***************************************************************************
                          slideLine.h  -  description
                             -------------------
    begin                : Thu Mar 15 2001
    copyright            : (C) 2001 by Haavard Froeiland
    email                : haavard@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SLIDELINE_H
#define SLIDELINE_H

#include <qwidget.h>
#include <qpainter.h>
#include <qstring.h>
#include <qpixmap.h>
#include <qtimer.h>
#include <qfontmetrics.h>
//#include <fstream.h>

class SlideLine: public QWidget
{
  Q_OBJECT

public:
 	SlideLine(QWidget *parent=0, const char *name=0);

  void setTeacherText(QString text);
  void setStudentText(QString text);
  static float offset;

protected:
 	void paintEvent  ( QPaintEvent * );
	void resizeEvent ( QResizeEvent * );

private:
  bool needRecreate;
  QString teacherText;
  QString studentText;
  QPixmap *pixmap;
  QFont font;
  int pixmapSize;
  QTimer *timer;
  int pos;
  bool textChanged;
  int cursorCount;
  int cursorX;
  int cursorY;
  int cursorHight;
  void calculateWidth();
  void calculateCursor();

private slots:
  void slide();

};

#endif
